@@ -335,6 +335,9 @@ impl Shadow {
     fn write_all(&mut self) -> SdResult<()> {
         self.gen_header()?;
 
+        //std env rerun
+        self.cargo_rerun_if_env_changed();
+
         self.gen_const()?;
 
         //write version function
@@ -345,6 +348,12 @@ impl Shadow {
         Ok(())
     }
 
+    fn cargo_rerun_if_env_changed(&self) {
+        for k in self.std_env.keys() {
+            println!("cargo:rerun-if-env-changed={}", k);
+        }
+    }
+
     fn gen_const(&mut self) -> SdResult<()> {
         for (k, v) in self.map.clone() {
             println!("cargo:rerun-if-env-changed={}", k);
@@ -355,10 +364,10 @@ impl Shadow {
 
     fn gen_header(&self) -> SdResult<()> {
         let desc = format!(
-            r#"/// Code generated by shadow-rs generator. DO NOT EDIT.
-/// Author by:https://www.github.com/baoyachi
-/// The build script repository:https://github.com/baoyachi/shadow-rs
-/// Create time by:{}"#,
+            r#"// Code generated by shadow-rs generator. DO NOT EDIT.
+// Author by:https://www.github.com/baoyachi
+// The build script repository:https://github.com/baoyachi/shadow-rs
+// Create time by:{}"#,
             BuildTime::Local(Local::now()).human_format()
         );
         writeln!(&self.f, "{}\n\n", desc)?;
@@ -366,7 +375,7 @@ impl Shadow {
     }
 
     fn write_const(&mut self, shadow_const: ShadowConst, val: ConstVal) -> SdResult<()> {
-        let desc = format!("/// {}", val.desc);
+        let desc = format!("#[doc=r#\"{}\"#]", val.desc);
 
         let define = match val.t {
             ConstType::OptStr => format!(
